@@ -1,5 +1,6 @@
 from .cache import SimpleCacheTest
 from .cli_scenarios import CliScenariosTest
+from .compatibility import CompatibilityTest
 from .markers import EnvironmentMarkersTest
 from .projects import ProjectMetadataTest
 from .requirements import RequirementsTest
@@ -9,6 +10,7 @@ from .resolution import ResolutionTest
 
 __all__ = [
     "CliScenariosTest",
+    "CompatibilityTest",
     "EnvironmentMarkersTest",
     "SimpleCacheTest",
     "RequirementsTest",
